@@ -24,7 +24,7 @@ was written by Jeff Waugh and is available at www.perkypants.org
 #   Ian Weller <ianweller@gmail.com>
 #
 # Released under the terms of the GNU GPL
-# http://www.gnu.org/copyleft/gpl.html
+# https://www.gnu.org/copyleft/gpl.html
 
 # Differences from the Perl version:
 #   There are no hardcoded nick colour preferences for jdub, cantanker and
@@ -56,13 +56,15 @@ import re
 import shlex
 import shutil
 import sys
+import datetime
 
 try:
     from urllib import quote
 except ImportError:
     from urllib.parse import quote
 
-from ._version import __version__ as VERSION, __date__ as RELEASE
+from ._version import (
+    __version__ as VERSION, __date__ as RELEASE, __homepage__ as HOMEPAGE)
 
 try:
     unicode
@@ -118,6 +120,7 @@ class LogParser(object):
         r'(?:\d{4}-\d{2}-\d{2}T|\d{2}-\w{3}-\d{4} |\w{3} \d{2} |\d{2} \w{3} )?' # Optional date
         r'\d\d:\d\d(:\d\d)?' # Mandatory HH:MM, optional :SS
         r')\]? +') # Optional ], mandatory space
+    TIMESTAMP_REGEXP = re.compile(r'^(\d+) +')
     NICK_REGEXP = re.compile(r'^<(.*?)(!.*?)?>\s')
     DIRCPROXY_NICK_REGEXP = re.compile(r'^<(.*?)(!.*)?>\s[\+-]?')
     JOIN_REGEXP = re.compile(r'^(?:\*\*\*|-->)\s.*joined')
@@ -159,6 +162,13 @@ class LogParser(object):
             else:
                 time = None
 
+            if time is None:
+                m = self.TIMESTAMP_REGEXP.match(line)
+                if m:
+                    time = datetime.datetime.utcfromtimestamp(
+                        int(m.group(1))).isoformat()
+                    line = line[len(m.group(0)):]
+
             m = self.NICK_REGEXP.match(line)
             if m:
                 nick = m.group(1)
@@ -415,8 +425,9 @@ class AbstractStyle(object):
     def timestamp_anchor(self, time):
         anchor = 't%s' % time
         if anchor in self._anchors:
+            org_anchor = anchor
             for n in itertools.count(2):
-                anchor = '%s-%d' % (anchor, n)
+                anchor = '%s-%d' % (org_anchor, n)
                 if anchor not in self._anchors:
                     break
         self._anchors.add(anchor)
@@ -450,8 +461,10 @@ class SimpleTextStyle(AbstractStyle):
     def foot(self):
         print("""
 <br>Generated by irclog2html.py %(VERSION)s by <a href="mailto:marius@pov.lt">Marius Gedminas</a>
- - find it at <a href="http://mg.pov.lt/irclog2html/">mg.pov.lt</a>!
-</tt></body></html>""" % {'VERSION': VERSION, 'RELEASE': RELEASE}, end=' ', file=self.outfile)
+ - find it at <a href="%(HOMEPAGE)s">%(HOMEPAGE)s</a>!
+ </tt></body></html>""" % {'VERSION': VERSION, 'RELEASE': RELEASE,
+                           'HOMEPAGE': escape(HOMEPAGE)},
+              end=' ', file=self.outfile)
 
     def servermsg(self, time, what, text):
         text = escape(text)
@@ -609,10 +622,11 @@ class XHTMLStyle(AbstractStyle):
         print("""
 <div class="generatedby">
 <p>Generated by irclog2html.py %(VERSION)s by <a href="mailto:marius@pov.lt">Marius Gedminas</a>
- - find it at <a href="http://mg.pov.lt/irclog2html/">mg.pov.lt</a>!</p>
+ - find it at <a href="%(HOMEPAGE)s">%(HOMEPAGE)s</a>!</p>
 </div>
 </body>
-</html>""" % {'VERSION': VERSION, 'RELEASE': RELEASE}, file=self.outfile)
+</html>""" % {'VERSION': VERSION, 'RELEASE': RELEASE,
+              'HOMEPAGE': escape(HOMEPAGE)}, file=self.outfile)
 
     def servermsg(self, time, what, text):
         """Output a generic server message.
@@ -784,9 +798,8 @@ class MediaWikiStyle(AbstractStyle):
     def foot(self):
         print('|}\n\nGenerated by irclog2html.py %(VERSION)s '
               'by [mailto:marius@pov.lt Marius Gedminas] - '
-              'find it at [http://mg.pov.lt/irclog2html '
-              'mg.pov.lt]!'
-              % {'VERSION': VERSION}, file=self.outfile)
+              'find it at [%(HOMEPAGE)s %(HOMEPAGE)s]!'
+              % {'VERSION': VERSION, 'HOMEPAGE': HOMEPAGE}, file=self.outfile)
 
 
 #
