@@ -179,7 +179,7 @@ def doctest_print_search_form():
         <BLANKLINE>
         <div class="generatedby">
         <p>Generated by irclogsearch.py ... by <a href="mailto:marius@pov.lt">Marius Gedminas</a>
-         - find it at <a href="http://mg.pov.lt/irclog2html/">mg.pov.lt</a>!</p>
+         - find it at <a href="https://mg.pov.lt/irclog2html/">https://mg.pov.lt/irclog2html/</a>!</p>
         </div>
         </body>
         </html>
@@ -231,7 +231,7 @@ def doctest_print_search_results():
         <BLANKLINE>
         <div class="generatedby">
         <p>Generated by irclogsearch.py ... by <a href="mailto:marius@pov.lt">Marius Gedminas</a>
-         - find it at <a href="http://mg.pov.lt/irclog2html/">mg.pov.lt</a>!</p>
+         - find it at <a href="https://mg.pov.lt/irclog2html/">https://mg.pov.lt/irclog2html/</a>!</p>
         </div>
         </body>
         </html>
@@ -301,7 +301,7 @@ def doctest_main_prints_form():
         <BLANKLINE>
         <div class="generatedby">
         <p>Generated by irclogsearch.py ... by <a href="mailto:marius@pov.lt">Marius Gedminas</a>
-         - find it at <a href="http://mg.pov.lt/irclog2html/">mg.pov.lt</a>!</p>
+         - find it at <a href="https://mg.pov.lt/irclog2html/">https://mg.pov.lt/irclog2html/</a>!</p>
         </div>
         </body>
         </html>
@@ -358,7 +358,7 @@ def doctest_main_searches():
         <BLANKLINE>
         <div class="generatedby">
         <p>Generated by irclogsearch.py ... by <a href="mailto:marius@pov.lt">Marius Gedminas</a>
-         - find it at <a href="http://mg.pov.lt/irclog2html/">mg.pov.lt</a>!</p>
+         - find it at <a href="https://mg.pov.lt/irclog2html/">https://mg.pov.lt/irclog2html/</a>!</p>
         </div>
         </body>
         </html>
