@@ -150,7 +150,7 @@ class TestLogFile(TestCase):
         self.create('somechannel-20130318.log')
         options = optparse.Values(dict(searchbox=True, dircproxy=True,
                                        pattern='*.log', force=False,
-                                       prefix='IRC logs for ',
+                                       prefix='IRC logs for ', output_dir=None,
                                        style='xhtmltable', title='IRC logs'))
         process(self.tmpdir, options)
         self.assertTrue(os.path.exists(self.filename('index.html')))
@@ -169,7 +169,7 @@ class TestLogFile(TestCase):
         self.create('somechannel-20130316.log.html')
         options = optparse.Values(dict(searchbox=True, dircproxy=True,
                                        pattern='*.log', force=False,
-                                       prefix='IRC logs for ',
+                                       prefix='IRC logs for ', output_dir=None,
                                        style='xhtmltable', title='IRC logs'))
         process(self.tmpdir, options)
         self.assertTrue(os.path.exists(self.filename('index.html')))
@@ -183,7 +183,7 @@ class TestLogFile(TestCase):
         self.create('index.html')
         options = optparse.Values(dict(searchbox=True, dircproxy=True,
                                        pattern='*.log', force=False,
-                                       prefix='IRC logs for ',
+                                       prefix='IRC logs for ', output_dir=None,
                                        style='xhtmltable', title='IRC logs'))
         os.chmod(self.filename('index.html'), 0o444)
         self.assertRaises(Error, process, self.tmpdir, options)
@@ -191,6 +191,33 @@ class TestLogFile(TestCase):
         # Restore the permissions so that our tearDown() can succeed.
         os.chmod(self.filename('index.html'), 0o644)
 
+    def test_process_with_output_dir(self):
+        self.create('somechannel-20130316.log')
+        options = optparse.Values(dict(searchbox=True, dircproxy=True,
+                                       pattern='*.log', force=False,
+                                       prefix='IRC logs for ',
+                                       output_dir=self.filename('new/out/dir'),
+                                       style='xhtmltable', title='IRC logs'))
+        process(self.tmpdir, options)
+        self.assertTrue(os.path.exists(self.filename('new/out/dir/index.html')))
+        self.assertTrue(os.path.exists(self.filename('new/out/dir/irclog.css')))
+        self.assertTrue(os.path.exists(
+            self.filename('new/out/dir/somechannel-20130316.log.html')))
+        if hasattr(os, 'symlink'):
+            self.assertTrue(os.path.exists(
+                self.filename('new/out/dir/latest.log.html')))
+
+    def test_process_with_output_dir_failure_to_mkdir(self):
+        self.create('somechannel-20130316.log')
+        self.create('out')
+        options = optparse.Values(dict(searchbox=True, dircproxy=True,
+                                       pattern='*.log', force=False,
+                                       prefix='IRC logs for ',
+                                       output_dir=self.filename('out'),
+                                       style='xhtmltable', title='IRC logs'))
+        with self.assertRaises(Error):
+            process(self.tmpdir, options)
+
     def test_main(self):
         self.create('somechannel-20130316.log')
         self.create('somechannel-20130316.log.html')
@@ -248,7 +275,7 @@ def doctest_write_index():
         <BLANKLINE>
         <div class="generatedby">
         <p>Generated by logs2html.py ... by <a href="mailto:marius@pov.lt">Marius Gedminas</a>
-         - find it at <a href="http://mg.pov.lt/irclog2html/">mg.pov.lt</a>!</p>
+         - find it at <a href="https://mg.pov.lt/irclog2html/">https://mg.pov.lt/irclog2html/</a>!</p>
         </div>
         </body>
         </html>
